@@ -1,4 +1,4 @@
-/* $Id: impact.c,v 1.34 2010/01/23 14:30:07 imil Exp $ */
+/* $Id: impact.c,v 1.28.2.1 2011/01/16 12:38:14 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -159,6 +159,9 @@ break_depends(Impacthead *impacthead, Pkgimpact *pimpact)
 
 		free_deptree(&fdphead);
 
+		if (!dep_break)
+			continue;
+
 		exists = 0;
 		/* check if rdp was already on impact list */
 		SLIST_FOREACH(rmimpact, impacthead, next)
@@ -167,7 +170,7 @@ break_depends(Impacthead *impacthead, Pkgimpact *pimpact)
 				break;
 			}
 
-		if (!dep_break || exists)
+		if (exists)
 			continue;
 
 		/* dependency break, insert rdp in remove-list */
