@@ -1,4 +1,4 @@
-/* $Id: pkglist.c,v 1.21 2010/01/23 14:30:07 imil Exp $ */
+/* $Id: pkglist.c,v 1.12.2.1.2.1 2011/01/16 22:25:21 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -293,18 +293,13 @@ find_exact_pkg(Plisthead *plisthead, const char *pkgarg)
 	return NULL;
 }
 
-/* order: <=1.0 >=2.0 ==1.2 -2.10
- *        ^     ^     ^     ^
- */
-
-static const char *extchars = "<>=-";
-
 /* end an expression with a delimiter */
 char *
 end_expr(Plisthead *plisthead, const char *str)
 {
 	Pkglist	*pkglist;
 	char	*expr, *p;
+	uint8_t	was_dep = 0;
 
 	/* enough space to add a delimiter */
 	XMALLOC(expr, (strlen(str) + 2) * sizeof(char));
@@ -323,10 +318,18 @@ end_expr(Plisthead *plisthead, const char *str)
 		}
 	}
 
-	/* simple package/dependency  case, parse string backwards
-	 *  until we find a delimiter: foo>=1.0
+	/* simple package/dependency case, parse string backwards
+	 * until we find a delimiter: foo>=1.0, bar>=1.2<2.0
 	 */
-	if ((p = match_dep_ext(expr, extchars)) != NULL) {
+	while ((p = match_dep_ext(expr, "<>=")) != NULL) {
+		*p++ = DELIMITER; /* terminate expr */
+		*p = '\0';
+		was_dep = 1;
+	}
+	/* expr was not a dewey pattern, it's a full package name,
+	 * strip the final dash if found
+	 */
+	if (!was_dep && (p = match_dep_ext(expr, "-")) != NULL) {
 		*p++ = DELIMITER; /* terminate expr */
 		*p = '\0';
 	}
