@@ -1,4 +1,4 @@
-/* $Id: tools.h,v 1.10 2010/01/03 14:07:29 imil Exp $ */
+/* $Id: tools.h,v 1.4.2.1 2011/01/16 12:38:14 imil Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -70,7 +70,7 @@
 #include <sys/utsname.h>
 #endif
 
-#if WANT_NBCOMPAT_H /* needed for strsep on SunOS < 5.11 */
+#if HAVE_NBCOMPAT_H /* needed for strsep on SunOS < 5.11 */
 #include <nbcompat.h>
 #include <nbcompat/string.h>
 #endif
